/**
 * @author Kon Lovett
 *
 * Demonstrate "crash" behavior with iOS & Ti SDK 5.0.2
 */

var dblClkTime = 500;

function getExistingContact(cntc) {
    var people = Ti.Contacts.getAllPeople();
    for (var i = 0,
        ilen = people.length; i < ilen; i++) {
        var person = people[i];
        if (person.fullName === cntc.fullName) {
            return person;
        }
    }
    return null;
}

var fakePerson = {
    // seems to be rqrd
    organization : "Contactstest Fake",
    fullName : "Contactstest Fake"
};

function genContactPersoninfo() {
    return fakePerson;
}

function genContactPersonSearchInfo() {
    var contact = {
        fullName : fakePerson.fullName
    };
    return contact;
}

/*
 * Main
 */

var window = Ti.UI.createWindow({
    backgroundColor : '#ffffff'
});

var firstView = Ti.UI.createView({
    layout : 'vertical'
});

var addButton = Ti.UI.createButton({
    title : "Add Fake Contact",
    height : Ti.UI.SIZE,
    width : Ti.UI.SIZE,
    top : 10 + 'dp',
    left : 5 + 'dp',
    // own properties
    clickTime : null
});

var rmvButton = Ti.UI.createButton({
    title : "Remove Fake Contact",
    height : Ti.UI.SIZE,
    width : Ti.UI.SIZE,
    top : 5 + 'dp',
    left : 5 + 'dp',
    // own properties
    clickTime : null
});

firstView.add(addButton);
firstView.add(rmvButton);
window.add(firstView);

function removeFromContacts(e) {
    // ## double-click prevention
    var currentTime = new Date();
    if (currentTime - e.source.clickTime < dblClkTime)
        return;
    e.source.clickTime = currentTime;

    rmvButton.removeEventListener('click', removeFromContacts);

    var person = getExistingContact(genContactPersonSearchInfo());
    // May not exist if rmvd by contacts app!
    if (person) {
        Ti.API.info('removePerson');
        Ti.Contacts.removePerson(person);
        Ti.API.info('save');
        Ti.Contacts.save();
        Ti.API.info('removed contact');
        alert('removed contact');
    } else {
        Ti.API.info('non-existing contact');
        alert('non-existing contact');
    }

    rmvButton.addEventListener('click', removeFromContacts);
}

function addToContacts(e) {
    // ## double-click prevention
    var currentTime = new Date();
    if (currentTime - e.source.clickTime < dblClkTime)
        return;
    e.source.clickTime = currentTime;

    addButton.removeEventListener('click', addToContacts);

    // Could be added by contacts app!
    if (!getExistingContact(genContactPersonSearchInfo())) {
        var person = Ti.Contacts.createPerson(genContactPersoninfo());
        Ti.API.info('added contact');
        alert('added contact');
    } else {
        Ti.API.info('existing contact');
        alert('existing contact');
    }

    addButton.addEventListener('click', addToContacts);
}

function addressBookAllowed() {
    addButton.addEventListener('click', addToContacts);
    rmvButton.addEventListener('click', removeFromContacts);
}

function addressBookDisallowed() {
    alert("Cannot access contacts. Please go to Settings > Privacy > Contacts to allow access");
}

window.open();

if (Ti.Contacts.contactsAuthorization === Ti.Contacts.AUTHORIZATION_AUTHORIZED) {
    addressBookAllowed();
} else if (Ti.Contacts.contactsAuthorization === Ti.Contacts.AUTHORIZATION_UNKNOWN) {
    Ti.Contacts.requestAuthorization(function(e) {
        if (e.success) {
            addressBookAllowed();
        } else {
            addressBookDisallowed(e);
        }
    });
} else {
    addressBookDisallowed();
}
